@@ -5,40 +5,46 @@ use warnings FATAL => 'all';
 
 use App::NDTools::INC;
 use App::NDTools::Slurp qw(s_dump s_load);
-use Encode::Locale qw(decode_argv);
+use Encode::Locale;
+use Encode qw(decode);
 use Getopt::Long qw(GetOptionsFromArray :config bundling);
 use Log::Log4Cli;
 use Struct::Path 0.80 qw(path);
 
-sub VERSION { "n/a" }
+our $VERSION = '0.29';
 
 sub arg_opts {
     my $self = shift;
 
     return (
         'dump-opts' => \$self->{OPTS}->{'dump-opts'},
-        'help|h' => sub { $self->usage; exit 0 },
+        'help|h' => sub {
+            $self->{OPTS}->{help} = 1;
+            die "!FINISH";
+        },
         'ifmt=s' => \$self->{OPTS}->{ifmt},
         'ofmt=s' => \$self->{OPTS}->{ofmt},
         'pretty!' => \$self->{OPTS}->{pretty},
         'verbose|v:+' => \$Log::Log4Cli::LEVEL,
-        'version|V' => sub { print $self->VERSION . "\n"; exit 0 },
+        'version|V' => sub {
+            $self->{OPTS}->{version} = 1;
+            die "!FINISH";
+        },
     );
 }
 
 sub check_args {
     my $self = shift;
 
-    unless (@_) {
-        log_error { 'At least one argument expected' };
-        return undef;
-    }
+    die_fatal 'At least one argument expected', 1 unless (@_);
 
     return $self;
 }
 
 sub configure {
-    return $_[0];
+    my $self = shift;
+
+    return $self->check_args(@{$self->{ARGV}});
 }
 
 sub defaults {
@@ -83,15 +89,27 @@ sub load_struct {
 }
 
 sub new {
-    my $self = bless { ARGV => \@_ }, shift;
+    my $self = bless {}, shift;
+
     $self->{OPTS} = $self->defaults();
+    $self->{ARGV} =
+        [ map { decode(locale => "$_", Encode::FB_CROAK) } @_ ? @_ : @ARGV ];
 
-    decode_argv(Encode::FB_CROAK);
     unless (GetOptionsFromArray ($self->{ARGV}, $self->arg_opts)) {
         $self->usage;
         die_fatal "Unsupported opts used", 1;
     }
 
+    if ($self->{OPTS}->{help}) {
+        $self->usage;
+        die_info, 0;
+    }
+
+    if ($self->{OPTS}->{version}) {
+        print $self->VERSION . "\n";
+        die_info, 0;
+    }
+
     $self->configure();
 
     if ($self->{OPTS}->{'dump-opts'}) {
